## Contributors ✨

This is a list of all project contributors powered by [All Contributors](https://allcontributors.org/), thanks goes to these wonderful people 🎉 ([emoji key](https://allcontributors.org/docs/en/emoji-key))

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/hammy2899"><img src="https://avatars2.githubusercontent.com/u/11588822?v=4" width="60px;" alt="Sean"/><br /><sub><b>Sean</b></sub></a><br /><a href="#question-hammy2899" title="Answering Questions">💬</a> <a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3Ahammy2899" title="Bug reports">🐛</a> <a href="#blog-hammy2899" title="Blogposts">📝</a> <a href="#business-hammy2899" title="Business development">💼</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=hammy2899" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=hammy2899" title="Documentation">📖</a> <a href="#design-hammy2899" title="Design">🎨</a> <a href="#example-hammy2899" title="Examples">💡</a> <a href="#ideas-hammy2899" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-hammy2899" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#maintenance-hammy2899" title="Maintenance">🚧</a> <a href="#platform-hammy2899" title="Packaging/porting to new platform">📦</a> <a href="#projectManagement-hammy2899" title="Project Management">📆</a> <a href="#review-hammy2899" title="Reviewed Pull Requests">👀</a> <a href="#security-hammy2899" title="Security">🛡️</a> <a href="#tool-hammy2899" title="Tools">🔧</a> <a href="#tutorial-hammy2899" title="Tutorials">✅</a> <a href="#talk-hammy2899" title="Talks">📢</a></td>
    <td align="center"><a href="https://github.com/prudho"><img src="https://avatars0.githubusercontent.com/u/7557689?v=4" width="60px;" alt="prudho"/><br /><sub><b>prudho</b></sub></a><br /><a href="#question-prudho" title="Answering Questions">💬</a> <a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3Aprudho" title="Bug reports">🐛</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=prudho" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=prudho" title="Documentation">📖</a> <a href="#example-prudho" title="Examples">💡</a> <a href="#ideas-prudho" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-prudho" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#review-prudho" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/ColinFrick"><img src="https://avatars1.githubusercontent.com/u/5517677?v=4" width="60px;" alt="Colin Frick"/><br /><sub><b>Colin Frick</b></sub></a><br /><a href="#question-ColinFrick" title="Answering Questions">💬</a> <a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3AColinFrick" title="Bug reports">🐛</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=ColinFrick" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=ColinFrick" title="Documentation">📖</a> <a href="#example-ColinFrick" title="Examples">💡</a> <a href="#ideas-ColinFrick" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-ColinFrick" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#review-ColinFrick" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://rasterbuster.lubber.de"><img src="https://avatars1.githubusercontent.com/u/18379884?v=4" width="60px;" alt="Marco 'Lubber' Wienkoop"/><br /><sub><b>Marco 'Lubber' Wienkoop</b></sub></a><br /><a href="#question-lubber-de" title="Answering Questions">💬</a> <a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3Alubber-de" title="Bug reports">🐛</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=lubber-de" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=lubber-de" title="Documentation">📖</a> <a href="#example-lubber-de" title="Examples">💡</a> <a href="#ideas-lubber-de" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-lubber-de" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#review-lubber-de" title="Reviewed Pull Requests">👀</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://www.exoego.net/"><img src="https://avatars2.githubusercontent.com/u/127635?v=4" width="60px;" alt="TATSUNO Yasuhiro"/><br /><sub><b>TATSUNO Yasuhiro</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3Aexoego" title="Bug reports">🐛</a> <a href="#blog-exoego" title="Blogposts">📝</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=exoego" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=exoego" title="Documentation">📖</a> <a href="#review-exoego" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/bartocc"><img src="https://avatars3.githubusercontent.com/u/47953?v=4" width="60px;" alt="Julien Palmas"/><br /><sub><b>Julien Palmas</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=bartocc" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/0xflotus"><img src="https://avatars3.githubusercontent.com/u/26602940?v=4" width="60px;" alt="0xflotus"/><br /><sub><b>0xflotus</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=0xflotus" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/rubenhbaca"><img src="https://avatars3.githubusercontent.com/u/19667830?v=4" width="60px;" alt="Ruben H. Baca"/><br /><sub><b>Ruben H. Baca</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=rubenhbaca" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/ventura-eesc"><img src="https://avatars1.githubusercontent.com/u/41117238?v=4" width="60px;" alt="ventura-eesc"/><br /><sub><b>ventura-eesc</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=ventura-eesc" title="Code">💻</a></td>
    <td align="center"><a href="http://www.brunobornsztein.com"><img src="https://avatars1.githubusercontent.com/u/3760?v=4" width="60px;" alt="Bruno Bornsztein"/><br /><sub><b>Bruno Bornsztein</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=bborn" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/MikeyFriedChicken"><img src="https://avatars3.githubusercontent.com/u/4342380?v=4" width="60px;" alt="Michael Ceber"/><br /><sub><b>Michael Ceber</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=MikeyFriedChicken" title="Code">💻</a></td>
    <td align="center"><a href="http://gammagames.net"><img src="https://avatars1.githubusercontent.com/u/7832163?v=4" width="60px;" alt="Jesse Lieberg"/><br /><sub><b>Jesse Lieberg</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=GammaGames" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://www.stockopedia.com/"><img src="https://avatars1.githubusercontent.com/u/412672?v=4" width="60px;" alt="Euan Goddard"/><br /><sub><b>Euan Goddard</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=euangoddard" title="Code">💻</a></td>
    <td align="center"><a href="https://madprof.net/"><img src="https://avatars3.githubusercontent.com/u/1070206?v=4" width="60px;" alt="Daniel"/><br /><sub><b>Daniel</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=danthedeckie" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/iarspider"><img src="https://avatars0.githubusercontent.com/u/636602?v=4" width="60px;" alt="iarspider"/><br /><sub><b>iarspider</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=iarspider" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/patilkiranm"><img src="https://avatars1.githubusercontent.com/u/3204107?v=4" width="60px;" alt="Kiran Patil"/><br /><sub><b>Kiran Patil</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=patilkiranm" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/douglasg14b"><img src="https://avatars1.githubusercontent.com/u/1400380?v=4" width="60px;" alt="Douglas Gaskell"/><br /><sub><b>Douglas Gaskell</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=douglasg14b" title="Code">💻</a> <a href="#talk-douglasg14b" title="Talks">📢</a></td>
    <td align="center"><a href="https://www.mvhnetworks.com"><img src="https://avatars0.githubusercontent.com/u/930315?v=4" width="60px;" alt="Ko Ko Zin"/><br /><sub><b>Ko Ko Zin</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=ko2in" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/dutrieux"><img src="https://avatars2.githubusercontent.com/u/1622751?v=4" width="60px;" alt="dutrieux"/><br /><sub><b>dutrieux</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=dutrieux" title="Code">💻</a></td>
    <td align="center"><a href="http://alexnewby.com"><img src="https://avatars2.githubusercontent.com/u/891192?v=4" width="60px;" alt="Alex"/><br /><sub><b>Alex</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=globophobe" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://twitter.com/y_ryu0220"><img src="https://avatars0.githubusercontent.com/u/14275842?v=4" width="60px;" alt="ryamaguchi0220"/><br /><sub><b>ryamaguchi0220</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=ryamaguchi0220" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/issues?q=author%3Aryamaguchi0220" title="Bug reports">🐛</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=ryamaguchi0220" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/egoisticalgoat"><img src="https://avatars3.githubusercontent.com/u/18332886?v=4" width="60px;" alt="Pascal"/><br /><sub><b>Pascal</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=egoisticalgoat" title="Documentation">📖</a></td>
    <td align="center"><a href="https://alexviscreanu.com"><img src="https://avatars2.githubusercontent.com/u/8055505?v=4" width="60px;" alt="Alex Viscreanu"/><br /><sub><b>Alex Viscreanu</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=aexvir" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=aexvir" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/rmarchiori"><img src="https://avatars3.githubusercontent.com/u/13880165?v=4" width="60px;" alt="Ricardo"/><br /><sub><b>Ricardo</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=rmarchiori" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/justkey007"><img src="https://avatars2.githubusercontent.com/u/36489637?v=4" width="60px;" alt="Juste Méthode B."/><br /><sub><b>Juste Méthode B.</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=justkey007" title="Code">💻</a></td>
    <td align="center"><a href="https://cruzdanilo.com"><img src="https://avatars2.githubusercontent.com/u/216636?v=4" width="60px;" alt="danilo neves cruz"/><br /><sub><b>danilo neves cruz</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=cruzdanilo" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/zombietfk"><img src="https://avatars1.githubusercontent.com/u/6123140?v=4" width="60px;" alt="ZombieTFK"/><br /><sub><b>ZombieTFK</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=zombietfk" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=zombietfk" title="Documentation">📖</a></td>
    <td align="center"><a href="https://shui91.github.io/portfolio"><img src="https://avatars2.githubusercontent.com/u/11592023?v=4" width="60px;" alt="Sherman Hui"/><br /><sub><b>Sherman Hui</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=shui91" title="Code">💻</a></td>
  </tr>
  <tr>
    <td align="center"><a href="http://rshalman.github.io"><img src="https://avatars2.githubusercontent.com/u/28634001?v=4" width="60px;" alt="Roman Shalman"/><br /><sub><b>Roman Shalman</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=RShalman" title="Code">💻</a></td>
    <td align="center"><a href="https://iwgx.github.io/amazing-things/"><img src="https://avatars1.githubusercontent.com/u/20817629?v=4" width="60px;" alt="Ilham Wahabi"/><br /><sub><b>Ilham Wahabi</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=iwgx" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/simondarke"><img src="https://avatars3.githubusercontent.com/u/2750476?v=4" width="60px;" alt="Simon Darke"/><br /><sub><b>Simon Darke</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=simondarke" title="Code">💻</a> <a href="https://github.com/fomantic/Fomantic-UI/commits?author=simondarke" title="Documentation">📖</a></td>
    <td align="center"><a href="https://www.travel21.fr"><img src="https://avatars1.githubusercontent.com/u/24317434?v=4" width="60px;" alt="RenonDis"/><br /><sub><b>RenonDis</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=RenonDis" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/josejbarneto"><img src="https://avatars0.githubusercontent.com/u/22933565?v=4" width="60px;" alt="Jose J Barneto"/><br /><sub><b>Jose J Barneto</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=josejbarneto" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/aardbol"><img src="https://avatars2.githubusercontent.com/u/14614620?v=4" width="60px;" alt="Leonardo"/><br /><sub><b>Leonardo</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=aardbol" title="Documentation">📖</a></td>
    <td align="center"><a href="https://bradleyw.me"><img src="https://avatars2.githubusercontent.com/u/10724949?v=4" width="60px;" alt="Bradley Watton"/><br /><sub><b>Bradley Watton</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=HypertextPP" title="Documentation">📖</a></td>
    <td align="center"><a href="https://lolhens.de"><img src="https://avatars1.githubusercontent.com/u/1524059?v=4" width="60px;" alt="Pierre Kisters"/><br /><sub><b>Pierre Kisters</b></sub></a><br /><a href="https://github.com/fomantic/Fomantic-UI/commits?author=LolHens" title="Code">💻</a></td>
  </tr>
</table>

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
